@@ -93,7 +93,7 @@ class ContactDatabaseManager(DatabaseManager):
         self.get_data()
         return self.category_collection.find({"identify_string": self.identify_string})
 
-    def get_contacts_info_in_group(self, category_id: int):
+    def get_contacts_info_in_category(self, category_id: int):
         return self.contact_collection.find({
             "identify_string": self.identify_string,
             "category_id": category_id
