@@ -84,6 +84,8 @@ class SmartqqClient:
 
     def message_preprocess(self, data):
         message = data.json()
+        if "errmsg" in message:
+            logger.info(str(message))
         if ("retcode" in message) and message["retcode"] != 0:
             if message["retcode"] == 103:
                 logger.info(OnlineChecker.check_online(self.login_data, self.session).content)
